================================================
Ultimate TicTacToe - Python Player & Game Engine
================================================

|Travis| |PyPI| |Coverage|

This repo contains a sample player and game engine for our `Ultimate TicTacToe`_ workshop.

Welcome!
========

Welcome! You're probably here because you're in a hackathon we're running. 

If so, make sure you've read the `Ultimate TTT Docs`_.

Once you're ready to write your player, you can find functions that will help you write your player in `API Reference`_

Contributors
============

The rest of this readme is if you're interested in contributing a player or even features to the game engine. If this is you:

1. **Thank you**!
2. Read on :)

Pull Requests
_____________

To make a contribution, please fork this repository and open a pull request. We are grateful for anything that can be
improved for the students taking part in our hackathons.

In general, any new functionality or player should be tested to ensure it is behaving as expected.

Running Tests
-------------

You (and Travis CI) can ensure our tests pass by running :code:`./setup.py test` in the root directory. Keep it that way!

.. Images and Links

.. |Travis| image:: https://travis-ci.org/socialgorithm/ultimate-ttt-py.svg?branch=master
    :target: https://travis-ci.org/socialgorithm/ultimate-ttt-py
.. |PyPI| image:: https://badge.fury.io/py/ultimate_ttt.svg
    :target: https://badge.fury.io/py/ultimate_ttt
.. |Coverage| image:: https://coveralls.io/repos/github/socialgorithm/ultimate-ttt-py/badge.svg?branch=master
    :target: https://coveralls.io/github/socialgorithm/ultimate-ttt-py?branch=master

.. _Ultimate TicTacToe: https://uttt.socialgorithm.org
.. _Ultimate TTT Docs: https://socialgorithm.org/ultimate-ttt-docs
.. _API Reference: https://ultimate-ttt-py.readthedocs.io/en/latest/
